@@ -4,13 +4,7 @@ use warnings ;
 use strict ;
 
 use WebService::TWFY::API ;
-
-## This key will not work, get you own at 
-## http://www.theyworkforyou.com/api/key
-
-my $rh = { key => 'abc1234' }; 
-
-my $api = WebService::TWFY::API->new( $rh );
+my $api = new WebService::TWFY::API ;
 
 my $rv = $api->query ( 'getConstituency', { 'postcode' => 'W128JL',
                                             'output'   => 'xml',
