@@ -5,8 +5,8 @@ use warnings ;
 
 use HTTP::Response ;
 
-our $VERSION = 0.07 ;
 our @ISA = qw( HTTP::Response ) ;
+our $VERSION = 0.01 ;
 
 =head1 NAME
 
@@ -14,7 +14,7 @@ WebService::TWFY::Response - API interface for TheyWorkForYou.com
 
 =head1 VERSION
 
-Version 0.07
+Version 0.01  
 
 =cut
 
@@ -22,8 +22,7 @@ Version 0.07
 
   use WebService::TWFY::API ;
   
-  my $rh = { key => 'ABC123' }; 
-  my $api = WebService::TWFY::API->new( $rh ) ;
+  my $api = new WebService::TWFY::API ;
 
   my $rv = $api->query ( 'getConstituency', { 'postcode' => 'W128JL'
                                               'output'   => 'xml',
@@ -47,18 +46,16 @@ Please feel free to send any bug reports and suggestions to my email listed belo
 
 For more information and useless facts on my life, you can also check my blog:
 
-  http://ffffruit.com/
+  http://idaru.blogspot.com/
+
 
 =head1 AUTHOR
 
     Spiros Denaxas
     CPAN ID: SDEN
+    Lokku Ltd
     s [dot] denaxas [@] gmail [dot]com
-    http://ffffruit.com
-
-=head1 SOURCE CODE
-
-The source code for his module is now on github L<https://github.com/spiros/WebService-TWFY-API>
+    http://idaru.blogspot.com
 
 =head1 COPYRIGHT
 
